Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3491)

Unified Diff: chrome/browser/browser_window.h

Issue 342048: Show a warning when the history files can't be read correctly.... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/browser.cc ('k') | chrome/browser/cocoa/browser_window_cocoa.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/browser_window.h
===================================================================
--- chrome/browser/browser_window.h (revision 30544)
+++ chrome/browser/browser_window.h (working copy)
@@ -205,8 +205,8 @@
// Shows the repost form confirmation dialog box.
virtual void ShowRepostFormWarningDialog(TabContents* tab_contents) = 0;
- // Shows a dialog to the user that the history is too new.
- virtual void ShowHistoryTooNewDialog() = 0;
+ // Shows a dialog to the user that something is wrong with the profile.
brettw 2009/10/30 21:52:43 Can you document the parameter here?
+ virtual void ShowProfileErrorDialog(int message) = 0;
// Show the bubble that indicates to the user that a theme is being installed.
virtual void ShowThemeInstallBubble() = 0;
« no previous file with comments | « chrome/browser/browser.cc ('k') | chrome/browser/cocoa/browser_window_cocoa.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698